@@ -14,6 +14,12 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
+# 获取CFS服务角色错误
+AUTHFAILURE_GETROLEFAILED = 'AuthFailure.GetRoleFailed'
+
 # 请求未CAM授权。
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
@@ -56,6 +62,36 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 快照策略未找到。
 INVALIDPARAMETER_AUTOPOLICYNOTFOUND = 'InvalidParameter.AutoPolicyNotFound'
 
+# 无效的快照保留时间。
+INVALIDPARAMETER_INVALIDALIVEDDAYS = 'InvalidParameter.InvalidAlivedDays'
+
+# 定期星期参数无效。
+INVALIDPARAMETER_INVALIDPARAMDAYOFWEEK = 'InvalidParameter.InvalidParamDayofWeek'
+
+# 定期小时 参数值错误。
+INVALIDPARAMETER_INVALIDPARAMHOUR = 'InvalidParameter.InvalidParamHour'
+
+# 无效的快照策略状态。
+INVALIDPARAMETER_INVALIDSNAPPOLICYSTATUS = 'InvalidParameter.InvalidSnapPolicyStatus'
+
+# 无效的文件系统快照参数名称 。
+INVALIDPARAMETER_INVALIDSNAPSHOTNAME = 'InvalidParameter.InvalidSnapshotName'
+
+# 无效的文件系统快照策略名称。
+INVALIDPARAMETER_INVALIDSNAPSHOTPOLICYNAME = 'InvalidParameter.InvalidSnapshotPolicyName'
+
+# 缺少策略相关参数。
+INVALIDPARAMETER_MISSINGPOLICYPARAM = 'InvalidParameter.MissingPolicyParam'
+
+# 文件系统快照名称超出上限。
+INVALIDPARAMETER_SNAPSHOTNAMELIMITEXCEEDED = 'InvalidParameter.SnapshotNameLimitExceeded'
+
+# 文件系统快照策略名称超过限制。
+INVALIDPARAMETER_SNAPSHOTPOLICYNAMELIMITEXCEEDED = 'InvalidParameter.SnapshotPolicyNameLimitExceeded'
+
+# 参数取值错误。
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
 # 用于保证请求幂等性的字符串长度超过限制（不能超过64字节）。
 INVALIDPARAMETERVALUE_CLIENTTOKENLIMITEXCEEDED = 'InvalidParameterValue.ClientTokenLimitExceeded'
 
@@ -98,6 +134,12 @@ INVALIDPARAMETERVALUE_INVALIDMOUNTTARGETIP = 'InvalidParameterValue.InvalidMount
 # 无效的网络类型。
 INVALIDPARAMETERVALUE_INVALIDNETINTERFACE = 'InvalidParameterValue.InvalidNetInterface'
 
+# DayOfMonth 参数错误
+INVALIDPARAMETERVALUE_INVALIDPARAMDAYOFMONTH = 'InvalidParameterValue.InvalidParamDayOfMonth'
+
+# IntervalDays 参数值错误
+INVALIDPARAMETERVALUE_INVALIDPARAMINTERVALDAYS = 'InvalidParameterValue.InvalidParamIntervalDays'
+
 # 权限组不属于该用户。
 INVALIDPARAMETERVALUE_INVALIDPGROUP = 'InvalidParameterValue.InvalidPgroup'
 
@@ -137,6 +179,9 @@ INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 # 标签键不能为空。
 INVALIDPARAMETERVALUE_INVALIDTAGKEY = 'InvalidParameterValue.InvalidTagKey'
 
+# 标签值为空或字符无效。
+INVALIDPARAMETERVALUE_INVALIDTAGVALUE = 'InvalidParameterValue.InvalidTagValue'
+
 # 无效的容量值。
 INVALIDPARAMETERVALUE_INVALIDTURBOCAPACITY = 'InvalidParameterValue.InvalidTurboCapacity'
 
@@ -176,6 +221,9 @@ INVALIDPARAMETERVALUE_MISSINGNAMEORDESCINFO = 'InvalidParameterValue.MissingName
 # 权限组名称不能为空。
 INVALIDPARAMETERVALUE_MISSINGPGROUPNAME = 'InvalidParameterValue.MissingPgroupName'
 
+# 缺少快照策略参数
+INVALIDPARAMETERVALUE_MISSINGPOLICYPARAM = 'InvalidParameterValue.MissingPolicyParam'
+
 # 未绑定存储包。
 INVALIDPARAMETERVALUE_MISSINGSTORAGERESOURCEPKG = 'InvalidParameterValue.MissingStorageResourcePkg'
 
@@ -200,6 +248,18 @@ INVALIDPARAMETERVALUE_PGROUPDESCINFOLIMITEXCEEDED = 'InvalidParameterValue.Pgrou
 # 权限组名称长度超过限制（不能超过64字节）。
 INVALIDPARAMETERVALUE_PGROUPNAMELIMITEXCEEDED = 'InvalidParameterValue.PgroupNameLimitExceeded'
 
+# 容量硬限制取值范围错误。
+INVALIDPARAMETERVALUE_QUOTACAPLIMITERROR = 'InvalidParameterValue.QuotaCapLimitError'
+
+# 文件硬限制取值范围错误。
+INVALIDPARAMETERVALUE_QUOTAFILELIMITERROR = 'InvalidParameterValue.QuotaFileLimitError'
+
+# USER ID类型错误。
+INVALIDPARAMETERVALUE_QUOTAUSERIDERROR = 'InvalidParameterValue.QuotaUserIdError'
+
+# 配额类型错误。
+INVALIDPARAMETERVALUE_QUOTAUSERTYPEERROR = 'InvalidParameterValue.QuotaUserTypeError'
+
 # 权限组规则和权限组不匹配。
 INVALIDPARAMETERVALUE_RULENOTMATCHPGROUP = 'InvalidParameterValue.RuleNotMatchPgroup'
 
@@ -209,6 +269,9 @@ INVALIDPARAMETERVALUE_TAGKEYFILTERLIMITEXCEEDED = 'InvalidParameterValue.TagKeyF
 # 标签键长度超过限制（不能超过127字节）。
 INVALIDPARAMETERVALUE_TAGKEYLIMITEXCEEDED = 'InvalidParameterValue.TagKeyLimitExceeded'
 
+# 标签值个数超过上限（10个）。
+INVALIDPARAMETERVALUE_TAGVALUEFILTERLIMITEXCEEDED = 'InvalidParameterValue.TagValueFilterLimitExceeded'
+
 # 标签值长度超过限制（不能超过255字节）。
 INVALIDPARAMETERVALUE_TAGVALUELIMITEXCEEDED = 'InvalidParameterValue.TagValueLimitExceeded'
 
@@ -221,6 +284,15 @@ INVALIDPARAMETERVALUE_UNAVAILABLEZONE = 'InvalidParameterValue.UnavailableZone'
 # ZoneId和Region不匹配。
 INVALIDPARAMETERVALUE_ZONEIDREGIONNOTMATCH = 'InvalidParameterValue.ZoneIdRegionNotMatch'
 
+# 缺少参数错误。
+MISSINGPARAMETER = 'MissingParameter'
+
+# 操作被拒绝。
+OPERATIONDENIED = 'OperationDenied'
+
+# 资源被占用。
+RESOURCEINUSE = 'ResourceInUse'
+
 # 文件系统数量达到上限。
 RESOURCEINSUFFICIENT_FILESYSTEMLIMITEXCEEDED = 'ResourceInsufficient.FileSystemLimitExceeded'
 
@@ -233,12 +305,21 @@ RESOURCEINSUFFICIENT_REGIONSOLDOUT = 'ResourceInsufficient.RegionSoldOut'
 # 规则条数超过上限。
 RESOURCEINSUFFICIENT_RULELIMITEXCEEDED = 'ResourceInsufficient.RuleLimitExceeded'
 
+# 文件系统过大，不支持快照
+RESOURCEINSUFFICIENT_SNAPSHOTSIZELIMITEXCEEDED = 'ResourceInsufficient.SnapshotSizeLimitExceeded'
+
 # 该子网下已无可用IP。
 RESOURCEINSUFFICIENT_SUBNETIPALLOCCUPIED = 'ResourceInsufficient.SubnetIpAllOccupied'
 
 # 该资源的标签个数达到最大限制。
 RESOURCEINSUFFICIENT_TAGLIMITEXCEEDED = 'ResourceInsufficient.TagLimitExceeded'
 
+# 标签限额不足。
+RESOURCEINSUFFICIENT_TAGQUOTASEXCEEDED = 'ResourceInsufficient.TagQuotasExceeded'
+
+# Turbo类型特殊容量文件系统数量限制
+RESOURCEINSUFFICIENT_TURBOSPECIALCAPACITYFILESYSTEMCOUNTLIMIT = 'ResourceInsufficient.TurboSpecialCapacityFileSystemCountLimit'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -254,6 +335,9 @@ RESOURCENOTFOUND_PGROUPNOTFOUND = 'ResourceNotFound.PgroupNotFound'
 # 权限规则不存在。
 RESOURCENOTFOUND_RULENOTFOUND = 'ResourceNotFound.RuleNotFound'
 
+# 快照ID 不存在。
+RESOURCENOTFOUND_SNAPSHOTNOTFOUND = 'ResourceNotFound.SnapshotNotFound'
+
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
@@ -263,5 +347,8 @@ UNSUPPORTEDOPERATION_BASICNETINTERFACENOTSUPPORTED = 'UnsupportedOperation.Basic
 # 用户已欠费, 请充值后重试。
 UNSUPPORTEDOPERATION_OUTOFSERVICE = 'UnsupportedOperation.OutOfService'
 
+# cfs角色未被授权。
+UNSUPPORTEDOPERATION_UNAUTHORIZEDCFSQCSROLE = 'UnsupportedOperation.UnauthorizedCfsQcsRole'
+
 # 用户未经过实名认证。
 UNSUPPORTEDOPERATION_UNVERIFIEDUSER = 'UnsupportedOperation.UnverifiedUser'
